@@ -57,6 +57,7 @@ QT_BEGIN_NAMESPACE
 class QMenu;
 class QPrinter;
 
+class QContextMenuBuilder;
 class QWebChannel;
 class QWebEngineContextMenuData;
 class QWebEngineFullScreenRequest;
@@ -64,6 +65,8 @@ class QWebEngineHistory;
 class QWebEnginePage;
 class QWebEnginePagePrivate;
 class QWebEngineProfile;
+class QWebEngineQuotaRequest;
+class QWebEngineRegisterProtocolHandlerRequest;
 class QWebEngineScriptCollection;
 class QWebEngineSettings;
 
@@ -128,6 +131,22 @@ public:
         SavePage,
         OpenLinkInNewBackgroundTab,
         ViewSource,
+
+        ToggleBold,
+        ToggleItalic,
+        ToggleUnderline,
+        ToggleStrikethrough,
+
+        AlignLeft,
+        AlignCenter,
+        AlignRight,
+        AlignJustified,
+        Indent,
+        Outdent,
+
+        InsertOrderedList,
+        InsertUnorderedList,
+
         WebActionCount
     };
     Q_ENUM(WebAction)
@@ -172,7 +191,9 @@ public:
         MediaAudioCapture = 2,
         MediaVideoCapture,
         MediaAudioVideoCapture,
-        MouseLock
+        MouseLock,
+        DesktopVideoCapture,
+        DesktopAudioVideoCapture
     };
     Q_ENUM(Feature)
 
@@ -222,28 +243,21 @@ public:
     void replaceMisspelledWord(const QString &replacement);
 
     virtual bool event(QEvent*);
-#ifdef Q_QDOC
-    void findText(const QString &subString, FindFlags options = FindFlags());
-    void findText(const QString &subString, FindFlags options, FunctorOrLambda resultCallback);
-#else
+
     void findText(const QString &subString, FindFlags options = FindFlags(), const QWebEngineCallback<bool> &resultCallback = QWebEngineCallback<bool>());
-#endif
+
     QMenu *createStandardContextMenu();
 
     void setFeaturePermission(const QUrl &securityOrigin, Feature feature, PermissionPolicy policy);
 
     void load(const QUrl &url);
     void load(const QWebEngineHttpRequest &request);
+    void download(const QUrl &url, const QString &filename = QString());
     void setHtml(const QString &html, const QUrl &baseUrl = QUrl());
     void setContent(const QByteArray &data, const QString &mimeType = QString(), const QUrl &baseUrl = QUrl());
 
-#ifdef Q_QDOC
-    void toHtml(FunctorOrLambda resultCallback) const;
-    void toPlainText(FunctorOrLambda resultCallback) const;
-#else
     void toHtml(const QWebEngineCallback<const QString &> &resultCallback) const;
     void toPlainText(const QWebEngineCallback<const QString &> &resultCallback) const;
-#endif
 
     QString title() const;
     void setUrl(const QUrl &url);
@@ -260,13 +274,8 @@ public:
 
     void runJavaScript(const QString& scriptSource);
     void runJavaScript(const QString& scriptSource, quint32 worldId);
-#ifdef Q_QDOC
-    void runJavaScript(const QString& scriptSource, FunctorOrLambda resultCallback);
-    void runJavaScript(const QString& scriptSource, quint32 worldId, FunctorOrLambda resultCallback);
-#else
     void runJavaScript(const QString& scriptSource, const QWebEngineCallback<const QVariant &> &resultCallback);
     void runJavaScript(const QString& scriptSource, quint32 worldId, const QWebEngineCallback<const QVariant &> &resultCallback);
-#endif
     QWebEngineScriptCollection &scripts();
     QWebEngineSettings *settings() const;
 
@@ -284,17 +293,13 @@ public:
     bool recentlyAudible() const;
 
     void printToPdf(const QString &filePath, const QPageLayout &layout = QPageLayout(QPageSize(QPageSize::A4), QPageLayout::Portrait, QMarginsF()));
-#ifdef Q_QDOC
-    void printToPdf(FunctorOrLambda resultCallback, const QPageLayout &layout = QPageLayout(QPageSize(QPageSize::A4), QPageLayout::Portrait, QMarginsF()));
-#else
     void printToPdf(const QWebEngineCallback<const QByteArray&> &resultCallback, const QPageLayout &layout = QPageLayout(QPageSize(QPageSize::A4), QPageLayout::Portrait, QMarginsF()));
-#endif
-
-#ifdef Q_QDOC
-    void print(QPrinter *printer, FunctorOrLambda resultCallback);
-#else
     void print(QPrinter *printer, const QWebEngineCallback<bool> &resultCallback);
-#endif // QDOC
+
+    void setInspectedPage(QWebEnginePage *page);
+    QWebEnginePage *inspectedPage() const;
+    void setDevToolsPage(QWebEnginePage *page);
+    QWebEnginePage *devToolsPage() const;
 
     const QWebEngineContextMenuData &contextMenuData() const;
 
@@ -311,6 +316,8 @@ Q_SIGNALS:
     void featurePermissionRequested(const QUrl &securityOrigin, QWebEnginePage::Feature feature);
     void featurePermissionRequestCanceled(const QUrl &securityOrigin, QWebEnginePage::Feature feature);
     void fullScreenRequested(QWebEngineFullScreenRequest fullScreenRequest);
+    void quotaRequested(QWebEngineQuotaRequest quotaRequest);
+    void registerProtocolHandlerRequested(QWebEngineRegisterProtocolHandlerRequest request);
 
     void authenticationRequired(const QUrl &requestUrl, QAuthenticator *authenticator);
     void proxyAuthenticationRequired(const QUrl &requestUrl, QAuthenticator *authenticator, const QString &proxyHost);
@@ -348,6 +355,7 @@ private:
     Q_PRIVATE_SLOT(d_func(), void _q_webActionTriggered(bool checked))
 #endif
 
+    friend class QContextMenuBuilder;
     friend class QWebEngineFullScreenRequest;
     friend class QWebEngineView;
     friend class QWebEngineViewPrivate;
@@ -356,6 +364,7 @@ private:
 #endif // QT_NO_ACCESSIBILITY
 };
 
+Q_DECLARE_OPERATORS_FOR_FLAGS(QWebEnginePage::FindFlags)
 
 QT_END_NAMESPACE
 
